pub enum AuthErrorCode {
InvalidRequest,
UnauthorizedClient,
AccessDenied,
UnsupportedResponseType,
ServerError,
TemporarilyUnavailable,
InvalidResource,
LoginRequired,
InteractionRequired,
}Variants
InvalidRequest
Description Protocol error, such as a missing required parameter.
Action: Fix and resubmit the request. This error is a development error typically caught during initial testing.
Description: The client application isn’t permitted to request an authorization code.
Action: This error usually occurs when the client application isn’t registered or isn’t added to the user’s tenant. The application can prompt the user with instruction for installing the application and adding it.
AccessDenied
Description: Resource owner denied consent.
Action: The client application can notify the user that it can’t continue unless the user consents.
UnsupportedResponseType
Description: The authorization server doesn’t support the response type in the request.
Action: Fix and resubmit the request. This error is a development error typically caught during initial testing. In the hybrid flow, this error signals that you must enable the ID token implicit grant setting on the client app registration.
ServerError
Description: The server encountered an unexpected error.
Action: Retry the request. These errors can result from temporary conditions. The client application might explain to the user that its response is delayed to a temporary error.
Description: The server is temporarily too busy to handle the request.
Action: Retry the request. The client application might explain to the user that its response is delayed because of a temporary condition.
InvalidResource
Description: The target resource is invalid because it does not exist, or it’s not correctly configured.
Action: This error indicates the resource, if it exists, hasn’t been configured in the tenant. The application can prompt the user with instruction for installing the application and adding it.
LoginRequired
Description: Too many or no users found.
Action: The client requested silent authentication (prompt=none), but a single user couldn’t be found. This error may mean there are multiple users active in the session, or no users. This error takes into account the tenant chosen. For example, if there are two accounts active and one social account, and social is chosen, silent authentication works.
InteractionRequired
Description: The request requires user interaction.
Action: Another authentication step or consent is required. Retry the request without prompt=none.